==> apache-bigtop-manager-1.0.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/zh_CN/overview.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  basic_info: '基本信息',
  service_info: '服务信息',
  detail: '详情',
  cluster_status: '集群状态',
  cluster_name: '集群名',
  cluster_desc: '集群备注',
  host_count: '主机数',
  service_count: '服务数',
  memory: '内存',
  chart: '图表',
  core_count: '核心数',
  disk_size: '磁盘大小',
  creator: '创建人',
  memory_usage: '内存使用率',
  cpu_usage: 'CPU使用率',
  unit_host: '个主机',
  unit_service: '个服务',
  unit_core: '个核心',
  unit_component: '个组件',
  component_info: '组件信息',
  host_status: '主机状态',
  hostname: '主机名',
  host_desc: '主机备注',
  component_count: '组件数',
  os: '操作系统',
  ip_v4: 'IPv4',
  ip_v6: 'IPv6',
  arch: '架构',
  service_status: '服务状态',
  service_name: '服务名',
  service_version: '服务版本',
  metrics: '指标监控',
  kerberos: 'Kerberos'
}

==> apache-bigtop-manager-1.1.0-src.tar.gz: bigtop-manager-src/bigtop-manager-ui/src/locales/zh_CN/overview.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
export default {
  basic_info: '基本信息',
  service_info: '服务信息',
  detail: '详情',
  cluster_status: '集群状态',
  cluster_name: '集群名',
  cluster_desc: '集群备注',
  host_count: '主机数',
  service_count: '服务数',
  memory: '内存',
  chart: '图表',
  core_count: '核心数',
  disk_size: '磁盘大小',
  creator: '创建人',
  memory_usage: '内存使用率',
  cpu_usage: 'CPU使用率',
  unit_host: '个主机',
  unit_service: '个服务',
  unit_core: '个核心',
  unit_component: '个组件',
  component_info: '组件信息',
  host_status: '主机状态',
  hostname: '主机名',
  host_desc: '主机备注',
  component_count: '组件数',
  os: '操作系统',
  ip_v4: 'IPv4',
  ip_v6: 'IPv6',
  arch: '架构',
  service_status: '服务状态',
  service_name: '服务名',
  service_version: '服务版本',
  metrics: '指标监控',
  kerberos: 'Kerberos',
  system_load: '系统负载',
  disk_io: '磁盘 I/O'
}
